v0.2.2
======
- Fix MANIFEST

v0.2.1
======
- Distribute Cython source.

v0.2
====
- Better reshaping for numpy arrays.

v0.1
====
- Integration using adaptive step-size and the Rosenbrock4 stepper supported.
